@@ -4,9 +4,10 @@ package Test::Kwalitee;
 BEGIN {
   $Test::Kwalitee::AUTHORITY = 'cpan:CHROMATIC';
 }
-# git description: v1.17-9-gd806079
-$Test::Kwalitee::VERSION = '1.18';
-# ABSTRACT: test the Kwalitee of a distribution before you release it
+# git description: v1.18-17-g2114f67
+$Test::Kwalitee::VERSION = '1.19';
+# ABSTRACT: Test the Kwalitee of a distribution before you release it
+# KEYWORDS: testing tests kwalitee CPANTS quality lint errors critic
 # vim: set ts=8 sw=4 tw=78 et :
 
 use Cwd;
@@ -106,17 +107,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords chromatic Karen Etheridge David Steinbrunner Gavin Sherlock Kenichi
-Ishigaki Nathan Haigh Zoffix Znet CPANTS changelog recognised Klausner
-Dolan
-
 =head1 NAME
 
-Test::Kwalitee - test the Kwalitee of a distribution before you release it
+Test::Kwalitee - Test the Kwalitee of a distribution before you release it
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -134,6 +131,8 @@ version 1.18
 
 =head1 DESCRIPTION
 
+=for stopwords CPANTS
+
 Kwalitee is an automatically-measurable gauge of how good your software is.
 That's very different from quality, which a computer really can't measure in a
 general sense.  (If you can, you've solved a hard problem in computer science.)
@@ -168,16 +167,24 @@ To disable a test, pass its name with a leading minus (C<->):
 The list of each available metric currently available on your
 system can be obtained with the C<kwalitee-metrics> command (with
 descriptions, if you pass C<--verbose> or C<-v>, but
-as of Test::Kwalitee 1.09 and L<Module::CPANTS::Analyse> 0.92, the tests include:
+as of Test::Kwalitee 1.19 and L<Module::CPANTS::Analyse> 0.93_01, the tests include:
 
 =over 4
 
 =item *
 
+has_abstract_in_pod
+
+Does the main module have a C<=head1 NAME> section with a short description of the distribution?
+
+=item *
+
 has_buildtool
 
 Does the distribution have a build tool file?
 
+=for stopwords changelog
+
 =item *
 
 has_changelog
@@ -225,6 +232,8 @@ Does the distribution have tests?
 
 metayml_conforms_to_known_spec
 
+=for stopwords recognised
+
 Does META.yml conform to any recognised META.yml specification?
 (For specs see
 L<http://module-build.sourceforge.net/META-spec-current.html>)
@@ -268,6 +277,8 @@ Does the distribution files all use strict?
 
 =head1 ACKNOWLEDGEMENTS
 
+=for stopwords Klausner Dolan
+
 With thanks to CPANTS and Thomas Klausner, as well as test tester Chris Dolan.
 
 =head1 SEE ALSO
@@ -284,6 +295,10 @@ L<Module::CPANTS::Analyse>
 
 =item *
 
+L<App::CPANTS::Lint>
+
+=item *
+
 L<Test::Kwalitee::Extra>
 
 =item *
